=======
Credits
=======

Contributors (by alphabetic order)
----------------------------------

* `ewjoachim <https://github.com/ewjoachim>`_
* `@brunobord <https://github.com/brunobord>`_
* `@k4nar <https://github.com/k4nar>`_
* `@zebuline <https://github.com/zebuline>`_
